/*
 * wq.app v1.2.0a1 - @wq/markdown 1.2.0-alpha.1
 * Markdown and syntax highlighting for @wq/app
 * (c) 2013-2019, S. Andrew Sheppard
 * https://wq.io/license
 */

import marked from 'marked';
import hljs from 'highlight.js/lib/highlight';
import bash from 'highlight.js/lib/languages/bash';
import css from 'highlight.js/lib/languages/css';
import javascript from 'highlight.js/lib/languages/javascript';
import markdown from 'highlight.js/lib/languages/markdown';
import python from 'highlight.js/lib/languages/python';
import scss from 'highlight.js/lib/languages/scss';
import xml from 'highlight.js/lib/languages/xml';

hljs.registerLanguage('bash', bash);
hljs.registerLanguage('css', css);
hljs.registerLanguage('javascript', javascript);
hljs.registerLanguage('markdown', markdown);
hljs.registerLanguage('python', python);
hljs.registerLanguage('scss', scss);
hljs.registerLanguage('xml', xml);

var md = {};

md.init = function (config) {
    if (!config) {
        config = {};
    } // Default variable names


    if (!config.output) {
        config.output = 'html'; // Look for {{html}} in template
    }

    if (!config.input) {
        config.input = 'markdown'; // Replace w/parse(this.markdown)
    }

    md.config = config;
};

md.context = function (context) {
    var output = '';

    if (context[md.config.input]) {
        output = md.parse(context[md.config.input]);
    }

    var result = {};
    result[md.config.output] = output;
    return result;
}; // Parsing function (can be used directly)


md.parse = function (value) {
    return md.postProcess(marked.parse(value));
}; // Override with custom post-processing function


md.postProcess = function (html) {
    if (md.config.postProcess) {
        return md.config.postProcess(html);
    } else {
        return html;
    }
}; // Connect markdown processor to code highlighter


marked.setOptions({
    highlight: function (code, lang) {
        return hljs.highlight(lang, code).value;
    }
}); // Run for server-rendered markdown

md.run = function ($page) {
    $page.find('pre code:not(.hljs)').each(function (i, el) {
        hljs.highlightBlock(el);
    });
};

export default md;
